# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/autos/car/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/autos/car/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Autos\\Car\\": "packages/autos/car/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Autos\Car\Providers\CarServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Car'  => Autos\Car\Facades\Car::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Autos\\CarTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Autos\Car\Providers\CarServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Autos\Car\Providers\CarServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Autos\Car\Providers\CarServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/car/{modulename}

**User**

    http://path-to-route-folder/user/car/{modulename}

**Public**

    http://path-to-route-folder/cars


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/car/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/car/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/car/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/car/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/car/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/car/{modulename}/{slug}
    METHOD: GET