<?php

namespace Autos\Car\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Autos\Car\Interfaces\CarModelRepositoryInterface;

class CarModelPublicController extends BaseController
{
    // use CarModelWorkflow;

    /**
     * Constructor.
     *
     * @param type \Autos\CarModel\Interfaces\CarModelRepositoryInterface $car_model
     *
     * @return type
     */
    public function __construct(CarModelRepositoryInterface $car_model)
    {
        $this->repository = $car_model;
        parent::__construct();
    }

    /**
     * Show car_model's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $car_models = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('car::car_model.names'))
            ->view('car::public.car_model.index')
            ->data(compact('car_models'))
            ->output();
    }


    /**
     * Show car_model.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $car_model = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($car_model->name . trans('car::car_model.name'))
            ->view('car::public.car_model.show')
            ->data(compact('car_model'))
            ->output();
    }

}
