<?php

namespace Autos\Car\Providers;

use Illuminate\Support\ServiceProvider;

class CarServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'car');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'car');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerCar();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerCar()
    {
        $this->app->bind('car', function($app) {
            return new Car($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Car', 'Lavalite\Car\Facades\Car');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('autos.car', function ($app) {
            return $this->app->make('Autos\Car\Car');
        });

        // Bind Car to repository
        $this->app->bind(
            'Autos\Car\Interfaces\CarRepositoryInterface',
            \Autos\Car\Repositories\Eloquent\CarRepository::class
        );        // Bind Brand to repository
        $this->app->bind(
            'Autos\Car\Interfaces\BrandRepositoryInterface',
            \Autos\Car\Repositories\Eloquent\BrandRepository::class
        );        // Bind CarModel to repository
        $this->app->bind(
            'Autos\Car\Interfaces\CarModelRepositoryInterface',
            \Autos\Car\Repositories\Eloquent\CarModelRepository::class
        );

        $this->app->register(\Autos\Car\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Autos\Car\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and car's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'autos.car'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeCar::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['autos.car'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('autos/car.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/car')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/car')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
