<?php

namespace Autos\Car\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Autos\Car\Models\Car;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Autos\Car\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/car/car/*')) {
            Route::bind('car', function ($car) {
                $carrepo = $this->app->make('Autos\Car\Interfaces\CarRepositoryInterface');
                return $carrepo->findorNew($car);
            });
        }
        if (Request::is('*/car/brand/*')) {
            Route::bind('brand', function ($brand) {
                $brandrepo = $this->app->make('Autos\Car\Interfaces\BrandRepositoryInterface');
                return $brandrepo->findorNew($brand);
            });
        }
        if (Request::is('*/car/car_model/*')) {
            Route::bind('car_model', function ($car_model) {
                $car_modelrepo = $this->app->make('Autos\Car\Interfaces\CarModelRepositoryInterface');
                return $car_modelrepo->findorNew($car_model);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
